<?php
/** 
*
* @package phpAR
* @version $Id: functions.php
* @copyright (c) 2007 gfxPros
* @website http://www.gfx-pros.com
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

/**
*
* Functions (16)
* +------------+
* file_create($file, $contents, $overwrite = false) - creates a file with the information provided
* file_add_after($file, $find, $add) - opens a file and finds a spot in the file then adds text after that spot
* file_add_before($file, $find, $add) - opens a file and finds a spot in the file then adds text before that spot
* file_replace($file, $find, $replace) - opens a file and finds a spot in the file then replaces the text in that spot
* file_compare($file, $file2) - compare two files returns true if they are identical and false if they are different
* file_temp_name($ext) - create a random name for a file returns the name
* file_rename($file, $new_file, $overwrite = false) - rename a file, set overwrite position to true to overwrite any files that might be there
* dir_create($dir) - create a directory
* dir_get_files($dir) - get a list of files in a directory
* dir_get_dirs($dir) - get a list of directories in a directory
* dir_count_files($dir) - get the number of files in a directory
* dir_count_dirs($dir) - get the number of directories in a directory
* dir_delete($dir, $deletefiles = false) - delete a directory, set the delete files position to true to delete the directory even if files are inside of it
* get_file_size($file) - returns file size in bytes, kb, mb, gb, and tb
* getmod($filename) - get the chmod of a directory
* create_thumbnail($src_image, $dest_file, $max_size) - creates a thumbnail at the specified location from the specified file
* get_file_type($file)
*
*/
function file_create($file, $contents, $overwrite = false)
{
	if (!file_exists($file))
	{
		//opens the file for editing
		$editfile = fopen($file, "w");
		//writes to the file
		fwrite($editfile, $contents);
		//saves the file
		fclose($editfile);
		return(true);
	}
	elseif ($overwrite)
	{
		//opens the file for editing
		$editfile = fopen($file, "w");
		//writes to the file
		fwrite($editfile, $contents);
		//saves the file
		fclose($editfile);
		return(true);
	}
	else
	{
		return(false);
	}
}

function file_add_after($file, $find, $add)
{
	if (file_exists($file))
	{
		//request for all the text inside the file
		$viewfile = file_get_contents($file);
		//checks if the file has already been changed
		$test = explode($add, $viewfile);
		if (@!$test['1'])
		{
			//splits the document where the find value is in the document
			$split = explode($find, $viewfile);
			//builds the file back together with the new text
			$newfile = $split['0'] . $find . $add . $split['1'];
			//opens the file for editing
			$editfile = fopen($file, "w");
			//writes to the file
			fwrite($editfile, $newfile);
			//saves the file
			fclose($editfile);
			return(true);
		}
	}
	else
	{
		return(false);
	}
}

function file_add_before($file, $find, $add)
{
	if (file_exists($file))
	{
		//request for all the text inside the file
		$viewfile = file_get_contents($file);
		//checks if the file has already been changed
		$test = explode($add, $viewfile);
		if (@!$test['1'])
		{
			//splits the document where the find value is in the document
			$split = explode($find, $viewfile);
			//builds the file back together with the new text
			$newfile = $split['0'] . $add . $find . $split['1'];
			//opens the file for editing
			$editfile = fopen($file, "w");
			//writes to the file
			fwrite($editfile, $newfile);
			//saves the file
			fclose($editfile);
			return(true);
		}
	}
	else
	{
		return(false);
	}
}

function file_replace($file, $find, $replace)
{
	if (file_exists($file))
	{
		//request for all the text inside the file
		$viewfile = file_get_contents($file);
		//checks if the file has already been changed
		$test = explode($replace, $viewfile);
		if (@!$test['1'])
		{
			//splits the document where the find value is in the document
			$split = explode($find, $viewfile);
			//builds the file back together with the new text in place of the old text
			$newfile = $split['0'] . $replace . $split['1'];
			//opens the file for editing
			$editfile = fopen($file, "w");
			//writes to the file
			fwrite($editfile, $newfile);
			//saves the file
			fclose($editfile);
			return(true);
		}
	}
	else
	{
		return(false);
	}
}

function file_compare($file, $file2)
{
	if (file_exists($file) && file_exists($file))
	{
		$viewfile = file_get_contents($file);
		$viewfile2 = file_get_contents($file2);
		if ($viewfile == $viewfile2)
		{
			return(true);
		}
	}
	else
	{
		return(false);
	}
}

function file_temp_name($ext)
{
	$name = md5(rand() * time());
	$s = rand(1, 10) . '-';
	$l = rand(5, 10) . '-';
	$name = substr($name, $s, $l);
	$name .= $ext;
	return($name);
}

function file_rename($file, $new_file, $overwrite = false)
{
	if (file_exists($file))
	{
		if (!file_exists($new_file))
		{
			rename($file, $new_file);
			return(true);
		}
		elseif ($overwrite)
		{
			unlink($new_file);
			rename($file, $new_file);
			return(true);
		}
		else
		{
			return(false);
		}
	}
	else
	{
		return(false);
	}
}

function dir_create($dir)
{
	if (!file_exists($dir))
	{
		mkdir($dir);
		return(true);
	}
	else
	{
		return(false);
	}
}

function dir_get_files($dir)
{
	$count = 0;
	$files = scandir($dir);
	foreach($files as $file)
	{
		if (is_file($dir . '/' . $file))
		{
			$file_list[$count] = $file;
			$count += 1;
		}
	}
	if (isset($file_list))
	{
		return($file_list);
	}
}

function dir_get_dirs($dir)
{
	$count = 0;
	$dirs = scandir($dir);
	foreach($dirs as $dir2)
	{
		if (is_dir($dir . '/' . $dir2))
		{
			$dir_list[$count] = $dir2;
			$count += 1;
		}
	}
	if (isset($dir_list))
	{
		return($dir_list);
	}
}

function dir_count_files($dir)
{
	if (is_dir($dir))
	{
		$count = 0;
		$files = scandir($dir);
		foreach($files as $file)
		{
			if (is_file($dir . '/' . $file))
			{
				$count += 1;
			}
		}
		return($count);
	}
}

function dir_count_dirs($dir)
{
	if (is_dir($dir))
	{
		$count = 0;
		$files = scandir($dir);
		foreach($files as $file)
		{
			if (is_dir($dir . '/' . $file))
			{
				$count += 1;
			}
		}
		$count -= 2;
		return($count);
	}
}

function dir_delete($dir, $deletefiles = false)
{
	if (@rmdir($dir))
	{
		return(true);
	}
	elseif (file_exists($dir))
	{
		if ($deletefiles)
		{
			$files = scandir($dir);
	
			foreach($files as $file)
			{
				$file2 = $dir . '/' . $file;
				if (!is_dir($file2))
				{
					if (is_file($file2))
					{
						print 'deleted ' . $file2 . '<br />';
						unlink($file2);
					}
				}
				else
				{
					if ($file != '.' && $file != '..')
					{
						print 'deleted ' . $file . '<br />';
						dir_delete($dir . '/' . $file, true);
					}
				}
			}
			if (@rmdir($dir))
			{
				return(true);
			}
			else
			{
				return(false);
			}
		}
		else
		{
			return(false);
		}
	}
}

function get_file_size($file) {
    $kb = 1024;
    $mb = 1024 * $kb;
    $gb = 1024 * $mb;
    $tb = 1024 * $gb;
	if ($file) {
		$size = filesize($file);
		if ($size < $kb) {
			$file_size = "$size Bytes";
		}
		elseif ($size < $mb) {
			$final = round($size/$kb, 2);
			$file_size = "$final KB";
		}
		elseif ($size < $gb) {
			$final = round($size/$mb, 2);
			$file_size = "$final MB";
		}
		elseif($size < $tb) {
			$final = round($size/$gb, 2);
			$file_size = "$final GB";
		} else {
			$final = round($size/$tb, 2);
			$file_size = "$final TB";
		}
	} else {
		return(false);
	}
	return($file_size);
}

function getmod($filename) {
   $val = 0;
   $perms = fileperms($filename);
   // Owner; User
   $val += (($perms & 0x0100) ? 0x0100 : 0x0000); //Read
   $val += (($perms & 0x0080) ? 0x0080 : 0x0000); //Write
   $val += (($perms & 0x0040) ? 0x0040 : 0x0000); //Execute
 
   // Group
   $val += (($perms & 0x0020) ? 0x0020 : 0x0000); //Read
   $val += (($perms & 0x0010) ? 0x0010 : 0x0000); //Write
   $val += (($perms & 0x0008) ? 0x0008 : 0x0000); //Execute
 
   // Global; World
   $val += (($perms & 0x0004) ? 0x0004 : 0x0000); //Read
   $val += (($perms & 0x0002) ? 0x0002 : 0x0000); //Write
   $val += (($perms & 0x0001) ? 0x0001 : 0x0000); //Execute

   // Misc
   $val += (($perms & 0x40000) ? 0x40000 : 0x0000); //temporary file (01000000)
   $val += (($perms & 0x80000) ? 0x80000 : 0x0000); //compressed file (02000000)
   $val += (($perms & 0x100000) ? 0x100000 : 0x0000); //sparse file (04000000)
   $val += (($perms & 0x0800) ? 0x0800 : 0x0000); //Hidden file (setuid bit) (04000)
   $val += (($perms & 0x0400) ? 0x0400 : 0x0000); //System file (setgid bit) (02000)
   $val += (($perms & 0x0200) ? 0x0200 : 0x0000); //Archive bit (sticky bit) (01000)

   return $val;
}

function create_thumbnail($src_image, $dest_file, $max_size)
{
	if (file_exists($src_image))
	{
		$size = getimagesize($src_image);
		
		if($size[0] > $size[1]) {
		  $divisor = $size[0] / $max_size;
		}
		else {
		  $divisor = $size[1] / $max_size;
		}
	
		$new_width = $size[0] / $divisor;
		$new_height = $size[1] / $divisor;
		
		settype($new_width, 'integer');
		settype($new_height, 'integer');
		
		$src_type = filetype($src_image);
		
		$src_type = array_pop(explode('.', $dest_file));
		
		if ($src_type == 'jpeg' || $src_type == 'jpg' || $src_type == 'pjpeg')
		{
			$src_image_big = imagecreatefromjpeg($src_image);
		}
		elseif ($src_type == 'png')
		{
			$src_image_big = imagecreatefrompng($src_image);
		}
		elseif ($src_type == 'gif')
		{
			$src_image_big = imagecreatefromgif($src_image);
		}
		else
		{
			return false;
		}
		
		print $src_type;
		
		$src_image_small = imagecreatetruecolor($new_width, $new_height);
	
		imagecopyresampled($src_image_small, $src_image_big, 0,0, 0,0, $new_width,$new_height, $size[0],$size[1]);
	
		imagedestroy($src_image_big);	
		
		
		
		if ($src_type == 'jpeg' || $src_type == 'jpg' || $src_type == 'pjpeg')
		{
			imagejpeg($src_image_small, $dest_file, 100);
		}
		elseif ($src_type == 'png')
		{
			imagepng($src_image_small, $dest_file, 100);
		}
		elseif ($src_type == 'gif')
		{
			imagegif($src_image_small, $dest_file, 100);
		}
		else
		{
			return false;
		}
		
		return true;
	}
	else
	{
		return false;
	}
}

function get_file_type($file)
{		
	return array_pop(explode('.', $file));
}
?>